@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -46,6 +46,8 @@ class __libcore EventTrigger: public BaseObject {
 	public:
 		EventTrigger();
 
+		virtual ~EventTrigger(){}
+
 		void setEvent(EventTriggerType evnt_type);
 		void setFunction(Function *func);
 		void setFilter(const QString &variable, const QStringList &values);
@@ -59,6 +61,8 @@ class __libcore EventTrigger: public BaseObject {
 		QStringList getFilter(const QString &variable);
 
 		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
+
+		virtual void updateDependencies() override;
 };
 
 #endif
