@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,14 +29,12 @@ DonateWidget::DonateWidget(QWidget *parent) : QWidget(parent)
 
 	GuiUtilsNs::createDropShadow(this, 5, 5, 30);
 
-	connect(hide_tb, &QToolButton::clicked,
-			[&](){
+	connect(hide_tb, &QToolButton::clicked, this, [this](){
 		hide();
 		emit s_hideRequested();
 	});
 
-	connect(donate_tb, &QToolButton::clicked,
-			[&](){
+	connect(donate_tb, &QToolButton::clicked, this, [this](){
 		QDesktopServices::openUrl(QUrl(GlobalAttributes::PgModelerDonateURL));
 		hide();
 		emit s_hideRequested();
